@@ -3,7 +3,7 @@
 
   Copyright (c) 1996 Roland Wunderling, Malte Zoeckler
   Copyright (c) 1998 Michael Meeks
-  Copyright (c) 1999-2000 Dragos Acostachioaie
+  Copyright (c) 1999-2001 Dragos Acostachioaie
 
   This file is part of DOC++.
 
@@ -47,10 +47,12 @@ char idlreserved[] = "any attribute boolean case char const context default"
 		     "interface long module Object octet oneway out raises"
 		     "readonly sequence short string struct switch TRUE typedef"
 		     "unsigned union void wchar wstring";
+char phpreserved[] = "class extends function include require";
 
 static McHashTable<const char *, char *> *cxxtable;
 static McHashTable<const char *, char *> *javatable;
 static McHashTable<const char *, char *> *idltable;
+static McHashTable<const char *, char *> *phptable;
 
 static McHashTable<const char*, Entry*>	namespace_roots(0);
 
@@ -113,6 +115,7 @@ Entry::Entry()
     hdoc          = 0;
     line          = 0;
     general	  = 0;
+    pureVirtual	  = false;
     fromUnknownPackage = false;
     docify = !onlyDocs;
 }
@@ -602,8 +605,18 @@ void Entry::makeRefs()
 	    }
 	}
     else
-	if((section & CLASS_SEC) || (section & INTERFACE_SEC))
-	    findBases();
+	if(language == LANG_PHP)
+	    {
+	    if((section & CLASS_SEC) || (section & INTERFACE_SEC))
+		for(i = 0; i < extends.size(); i++)
+		    {
+		    tmp = *(extends[i]);
+		    addBaseClass(tmp.c_str(), PUBL);
+		    }	  
+	    }
+	else
+	    if((section & CLASS_SEC) || (section & INTERFACE_SEC))
+		findBases();
 
     for(i = 0; i < sublist.size(); ++i)
 	sublist[i]->makeRefs();
@@ -730,6 +743,20 @@ void setupLanguageHash()
 	else
 	    tmp++;
 
+    // PHP
+    st = phpreserved;
+    tmp = st;
+    phptable = new McHashTable<const char *, char *>("");
+    while(*tmp)
+	if(*tmp == ' ')
+	    {
+	    *tmp = 0;
+	    phptable->insert(st, "1");
+	    st = ++tmp;
+	    }
+	else
+	    tmp++;
+
     // Setup cache as well
     for(lp = 0; lp < MAX_CACHE; lp++)
 	{
@@ -753,7 +780,7 @@ Entry *findJavaPackage(McString n, Entry *root, Entry *p)
     int i = n.index('.'), j;
     McString *pkgName;
 
-    if(!root)
+    if(!root || language == LANG_PHP)
 	return 0;
 
     if(root->section == EMPTY_SEC)
@@ -1108,6 +1135,13 @@ bool mergeEntry(Entry *ccentry)
     if(scope < 1 || ccentry->fullName[scope] != ':')
 	noScope = true;
 
+    if(language == LANG_PHP)
+	{
+	scope = ccentry->fullName.rindex('.');
+	if(scope < 1 || ccentry->fullName[scope] != '.')
+	    noScope = true;
+	}
+
     McString unqualified_name(ccentry->fullName, scope + 2,
 	ccentry->fullName.size() - scope - 3);
     McString parent_name(ccentry->fullName, 0, scope);
@@ -1220,6 +1254,9 @@ Entry *searchRefEntry(McString &name, Entry *entry)
 	case LANG_IDL:
 	    table = idltable;
 	    break;
+	case LANG_PHP:
+	    table = phptable;
+	    break;
 	default:
 	    table = 0;
 	}
