@@ -2,8 +2,7 @@
   McHashTable.cc
 
   Copyright (c) 1996 Roland Wunderling, Malte Zoeckler
-  Copyright (c) 1998 Michael Meeks
-  Copyright (c) 1999 Dragos Acostachioaie
+  Copyright (c) 1999-2000 Dragos Acostachioaie
 
   This file is part of DOC++.
 
@@ -25,15 +24,16 @@
 #include "McHashTable.h"
 
 // One word summary of a string. This is taken from Tcl.
-
-int hash(const char* str)
+int hash(const char *str)
 {
     int result = 0;
-    while (1) {
+    while(1)
+	{
 	char c = *str++;
-	if (c == 0) break;
-	result += (result<<3) + c;
-    }
+	if(c == 0)
+	    break;
+	result += (result << 3) + c;
+	}
     return result;
 }
 
@@ -42,9 +42,9 @@ int hash(int i)
     return i;
 }
 
-int compare(const char* str1, const char* str2)
+int compare(const char *str1, const char *str2)
 {
-    return strcmp(str1,str2);
+    return strcmp(str1, str2);
 }
 
 int compare(int i1, int i2)
