@@ -2,8 +2,7 @@
   McWildMatch.cc
 
   Copyright (c) 1996 Roland Wunderling, Malte Zoeckler
-  Copyright (c) 1998 Michael Meeks
-  Copyright (c) 1999 Dragos Acostachioaie
+  Copyright (c) 1999-2000 Dragos Acostachioaie
 
   This file is part of DOC++.
 
@@ -22,49 +21,46 @@
   Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-int mcWildMatch(const char* str, const char* pat)
+bool mcWildMatch(const char *str, const char *pat)
 {
     register int i = 0, j = 0;
-    int	star = 0, k = 0;
+    int	k = 0;
+    bool star = false;
 
-    while (pat[i] != '\0'&& str[j] != '\0')
-    {
-	if (pat[i] == '*')
+    while(pat[i] != '\0' && str[j] != '\0')
 	{
-	    star = 1;
-	    while (pat[i] == '*') i++;
+	if(pat[i] == '*')
+	    {
+	    star = true;
+	    while(pat[i] == '*')
+		i++;
 	    k = i;
-	}
-	else
-	{
-	    if (pat[i] == '?' || pat[i] == str[j])
-	    {
-	        j++; i++;
 	    }
-	    else
+	else
 	    {
-		if (star == 0)
+	    if(pat[i] == '?' || pat[i] == str[j])
 		{
-		    return 0;
+	        j++;
+		i++;
 		}
+	    else
+		{
+		if(!star)
+		    return false;
 	        i = k;
 		j++;
+		}
 	    }
 	}
-    }
 
-    while (pat[i] == '*') i++;
+    while(pat[i] == '*')
+	i++;
 
-    if (pat[i] == str[j])
-    {
-	return 1;
-    }
-    else if (pat[i] == '\0' && (pat[i-1] == '*' || pat[i-1] == '?'))
-    {
-	return 1;
-    }
+    if(pat[i] == str[j])
+	return true;
     else
-    {
-	return 0;
-    }
+	if(pat[i] == '\0' && (pat[i - 1] == '*' || pat[i - 1] == '?'))
+	    return true;
+	else
+	    return false;
 }
