@@ -2,8 +2,7 @@
   McWildMatch.h
 
   Copyright (c) 1996 Roland Wunderling, Malte Zoeckler
-  Copyright (c) 1998 Michael Meeks
-  Copyright (c) 1999 Dragos Acostachioaie
+  Copyright (c) 1999-2000 Dragos Acostachioaie
 
   This file is part of DOC++.
 
@@ -25,13 +24,13 @@
 #ifndef _MC_WILD_MATCH_H
 #define _MC_WILD_MATCH_H
 
-/** Matches string against pattern containing wildcards '?' and '*'.
+/** Matches string against pattern containing wildcards ``?'' and ``*''.
 
     This routine tests a string against a wild card pattern. The wild 
-    characters are '*' and '?'. '*' matches an arbitrary sequence of
-    characters while '?' matches any single character. Returns 1 if the
-    match is successful, 0 otherwise.
+    characters are ``*'' and ``?''. ``*'' matches an arbitrary sequence of
+    characters while ``?'' matches any single character. Returns #true# if the
+    match is successful, #false# otherwise.
 */
-int mcWildMatch(const char* str, const char* pattern);
+bool mcWildMatch(const char *str, const char *pattern);
 
 #endif
