@@ -45,8 +45,9 @@ public:
 
     /// constructor for name
     ClassGraph(const McString& nm, int ind)
-	: firstLine(this), nextLine(0), indent(ind), entry(0), name(nm)
+	: nextLine(0), indent(ind), entry(0), name(nm)
     {
+	firstLine = this;
     }
 
     void addAllChilds();
