@@ -3,7 +3,7 @@
 
   Copyright (c) 1996 Roland Wunderling, Malte Zoeckler
   Copyright (c) 1998 Michael Meeks
-  Copyright (c) 1999-2001 Dragos Acostachioaie
+  Copyright (c) 1999-2002 Dragos Acostachioaie
 
   This file is part of DOC++.
 
@@ -33,14 +33,14 @@
 #include "config.h"
 #include "portability.h"
 
+#include <gettext.h>
 #ifdef ENABLE_NLS
-#include <libintl.h>
 #define _(x) gettext(x)
 #else
 #define _(x) (x)
 #endif
 
-#define DOCXX_VERSION	"3.4.8"
+#define DOCXX_VERSION	"3.4.10"
 
 extern FILE			*out;			// output FILE
 extern char			language;		// language
@@ -63,6 +63,7 @@ extern bool			upArrows;		// --upwards-arrows
 extern bool			verb;			// --verbose
 extern bool			idl;
 extern bool			doDOCBOOK;
+extern bool			doDOCBOOKXML;
 extern bool			scanIncludes;		// --scan-includes
 extern McDArray<McString *>	inputFiles;
 
@@ -328,11 +329,13 @@ struct namespace_entry {
 
 extern Entry*	root;
 extern void	printYYDOC(Entry *cur, const char *str, int escPrcnt = 1);
-extern void	printYYDOCdb(Entry *cur, const char *str, int escPrcnt = 1);
+extern void	printYYDOCdbsgml(Entry *cur, const char *str, int escPrcnt = 1);
+extern void	printYYDOCdbxml(Entry *cur, const char *str, int escPrcnt = 1);
 
 // parsing comands
 extern void	listing    (char *str);
-extern void	usermanDB  (char *str, Entry *root);
+extern void	usermanDBsgml (char *str, Entry *root);
+extern void	usermanDBxml  (char *str, Entry *root);
 extern void	usermanTeX (char *str, Entry *root);
 extern void	parseCpp   (Entry *rt);
 extern void	parseJava  (Entry *rt);
