@@ -3,7 +3,7 @@
 
   Copyright (c) 1996 Roland Wunderling, Malte Zoeckler
   Copyright (c) 1998 Michael Meeks
-  Copyright (c) 1998-2000 Dragos Acostachioaie
+  Copyright (c) 1998-2001 Dragos Acostachioaie
 
   This file is part of DOC++.
 
@@ -264,7 +264,7 @@ void copyright(FILE *f)
     if(footer.length() <= 0 && ownFooter.length() == 0)
 	{
 	fprintf(f, "<BR>\n");
-	fprintf(f, _("This page was generated with the help of <A HREF=\"http://www.linuxsupportline.com/~doc++\">DOC++</A>.\n"));
+	fprintf(f, _("This page was generated with the help of <A HREF=\"http://docpp.sourceforge.net\">DOC++</A>.\n"));
 	fprintf(f, "</BODY>\n");
 	fprintf(f, "</HTML>\n");
 	}
@@ -666,7 +666,10 @@ void MemberWriter::writeMember(Entry *entry, bool link, bool withSub)
 	    fprintf(f, "<IMG ALT=\"[more]\" BORDER=0 SRC=icon1.gif>");
 	    fprintf(f, "%s <B><A HREF=\"#DOC.", entry->htype);
 	    entry->dumpNumber(f);
-	    fprintf(f, "\">%s</A></B>%s\n", entry->hname, entry->hargs);
+	    fprintf(f, "\">%s</A></B>%s", entry->hname, entry->hargs);
+	    if(entry->pureVirtual)
+		fprintf(f, " = 0");
+	    fprintf(f, "\n");
 	    }
 	else
 	    {
@@ -1137,7 +1140,7 @@ class MemberList {
 	    McString signature = e->name;
 	    char *tmp;
 
-	    if(language == LANG_JAVA)
+	    if(language == LANG_JAVA || language == LANG_PHP)
 		signature += e->args;
 	    tmp = strdup(signature.c_str());
 	    Entry **val = list.insert(tmp);
@@ -1373,6 +1376,8 @@ void writeDoc(FILE *f, Entry *entry)
 	fprintf(f, "<IMG ALT=\"o\" BORDER=0 SRC=icon2.gif><TT><B>%s %s",
 	    type, entry->hname);
 	fprintf(f, "%s", args);	
+	if(entry->pureVirtual)
+	    fprintf(f, " = 0");
 	fprintf(f, "</B></TT>\n");
 
 	if(entry->doc.length() > 0)
