@@ -3,7 +3,7 @@
 
   Copyright (c) 1996 Roland Wunderling, Malte Zoeckler
   Copyright (c) 1998 Michael Meeks
-  Copyright (c) 1998-2001 Dragos Acostachioaie
+  Copyright (c) 1998-2002 Dragos Acostachioaie
 
   This file is part of DOC++.
 
@@ -65,14 +65,17 @@ void help()
     printf(_("  -q  --quick            optimize for speed instead of size\n"));
     printf(_("  -Q  --quantel          Quantel extensions, folding & appended comments\n"));
     printf(_("  -R  --internal-doc     generate internal documentation\n"));
-    printf(_("  -t  --tex              generate TeX output instead of HTML\n"));
     printf(_("  -u  --upwards-arrows   upwards arrows in class graphs\n"));
     printf(_("  -v  --verbose          turn verbose mode on\n"));
     printf(_("  -V  --version          output version information and exit\n"));
     printf(_("  -y  --scan-includes    scan `#include'ed header files\n"));
     printf(_("  -Y  --idl              parse IDL instead of C/C++\n"));
-    printf(_("  -z  --php              parse PHP instead of C/C++\n"));
-    printf(_("  -Z  --docbook          generate DocBook SGML instead of HTML\n\n"));
+    printf(_("  -z  --php              parse PHP instead of C/C++\n\n"));
+
+    printf(_("Alternate output types instead of HTML:\n"));
+    printf(_("  -t  --tex              TeX output output\n"));
+    printf(_("  -Z  --docbook          DocBook SGML output\n"));
+    printf(_("  -L  --docbookxml       DocBook XML output\n"));
 
     printf(_("Additional options for HTML output:\n"));
     printf(_("  -a  --tables           use tables instead of description lists\n"));
@@ -109,7 +112,7 @@ void help()
     printf(_("  -s  --source           generate source code listing\n"));
     printf(_("  -X  --hide-index       don't generate index at section start\n\n"));
 
-    printf(_("Mail bug reports and suggestions to <docpp@egroups.com>\n"));
+    printf(_("Mail bug reports and suggestions to <docpp-users@lists.sourceforge.net>\n"));
 }
 
 void missingArg(char *s)
@@ -171,6 +174,7 @@ int main(int argc, char **argv)
 	{ "idl", no_argument, 0, 'Y' },
         { "php", no_argument, 0, 'z' },
 	{ "docbook", no_argument, 0, 'Z' },
+	{ "docbookxml", no_argument, 0, 'L' },
 
         // additional options for HTML output
         { "tables", no_argument, 0, 'a' },
@@ -210,7 +214,7 @@ int main(int argc, char **argv)
 
     opterr = 0;
 
-    while((c = getopt_long(argc, argv, "+AcC:hHI:Jkn:pqQRtuvVyYZabB:d:fFgGijmMPST:wWx:K:e:D:lo:sX",
+    while((c = getopt_long(argc, argv, "+AcC:hHI:Jkn:pqQRtuvVyYZLabB:d:fFgGijmMPST:wWx:K:e:D:lo:sX",
 	long_options, (int *)0)) != EOF)
 	switch(c)
 	    {
@@ -249,6 +253,9 @@ int main(int argc, char **argv)
     	    case 'k':
     		trivialGraphs = true;
 		break;
+	    case 'L':
+		doDOCBOOKXML = true;
+		break;
 	    case 'N':
 		noDefines = true;
 		break;
@@ -519,7 +526,11 @@ int main(int argc, char **argv)
     // read configuration file (if possible)
     if(configFile.length() > 0)
 	{
+#ifdef WIN32
+	ifstream f(configFile.c_str(), ios::nocreate|ios::in);
+#else
 	ifstream f(configFile.c_str());
+#endif
 	if(!f)
 	    {
 	    if(configFile != "doc++.conf")
@@ -641,9 +652,12 @@ int main(int argc, char **argv)
 	usermanTeX(inputFile, root);
     else
 	if(doDOCBOOK)
-	    usermanDB(inputFile, root);
-	else
-	    doHTML(outputDir.c_str(), root);
+	    usermanDBsgml(inputFile, root);
+        else
+	    if(doDOCBOOKXML)
+		usermanDBxml(inputFile, root);
+	    else
+		doHTML(outputDir.c_str(), root);
 
     // Create GIFs (if any)
     gifNum = gifs.num();
