@@ -2,7 +2,7 @@
   tex2gif.cc
 
   Copyright (c) 1996 Roland Wunderling, Malte Zoeckler
-  Copyright (c) 1999-2000 Dragos Acostachioaie
+  Copyright (c) 1999-2001 Dragos Acostachioaie
 
   This file is part of DOC++.
 
@@ -198,7 +198,7 @@ void makeGifs(const char *dir, const char *gifdb)
 
 	    sprintf(buf, "pnmscale -xscale .333 -yscale .333 dxxtmp.pnm | "
 		"pnmgamma .9 | ppmquant 256 |"
-		"ppmtogif -transparent rgb:ffff/ffff/ffff > g%06d.gif", n);
+		"ppmtogif -transparent rgb:ac/ac/ac > g%06d.gif", n);
 	    _system(buf);
 
 	    sprintf(buf, "dxx%04d.eps", i);
